@@ -131,7 +131,6 @@ struct _GVfsBackendDnsSd
   GList *files; /* list of LinkFiles */
 
   GList *browsers;
-  GList *resolvers;
 };
 
 typedef struct _GVfsBackendDnsSd GVfsBackendDnsSd;
@@ -567,19 +566,19 @@ resolve_callback (AvahiServiceResolver *r,
   char *path;
 
   if (event == AVAHI_RESOLVER_FAILURE)
-    goto out;
-
+    return;
+  
   /* Link-local ipv6 address, can't make a uri from this, ignore */
   if (address->proto == AVAHI_PROTO_INET6 &&
       address->data.ipv6.address[0] == 0xfe &&
       address->data.ipv6.address[1] == 0x80)
-    goto out;
-
+    return;
+  
   file = lookup_link_file_by_name_and_type (backend,
 					    name, type);
 
   if (file != NULL)
-    goto out;
+    return;
 
   file = link_file_new (name, type, domain, host_name, protocol,
 			address, port, txt);
@@ -592,10 +591,6 @@ resolve_callback (AvahiServiceResolver *r,
 			    path,
 			    NULL);
   g_free (path);
-
- out:
-  backend->resolvers = g_list_remove (backend->resolvers, r);
-  avahi_service_resolver_free (r);
 }
 
 static void
@@ -622,15 +617,18 @@ browse_callback (AvahiServiceBrowser *b,
       
     case AVAHI_BROWSER_NEW:
       client = get_global_avahi_client ();
-
+      
+      /* We ignore the returned resolver object. In the callback
+	 function we free it. If the server is terminated before
+	 the callback function is called the server will free
+	 the resolver for us. */
+      
       sr = avahi_service_resolver_new (client, interface, protocol,
 				       name, type, domain, AVAHI_PROTO_UNSPEC, 0, resolve_callback, backend);
 
       if (sr == NULL) 
 	g_warning ("Failed to resolve service name '%s': %s\n", name, avahi_strerror (avahi_client_errno (client)));
-      else
-	backend->resolvers = g_list_prepend (backend->resolvers, sr);
-
+      
       break;
       
     case AVAHI_BROWSER_REMOVE:
@@ -801,9 +799,6 @@ g_vfs_backend_dns_sd_finalize (GObject *object)
 
   dnssd_backends = g_list_remove (dnssd_backends, backend);
 
-  remove_browsers (backend);
-  g_list_free_full (backend->resolvers, (GDestroyNotify)avahi_service_resolver_free);
-
   if (backend->mount_spec)
     g_mount_spec_unref (backend->mount_spec);
   
@@ -826,6 +821,7 @@ try_query_fs_info (GVfsBackend *backend,
                    GFileAttributeMatcher *matcher)
 {
   g_file_info_set_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE, "dns-sd");
+  g_file_info_set_attribute_boolean (info, G_FILE_ATTRIBUTE_FILESYSTEM_REMOTE, TRUE);
   g_vfs_job_succeeded (G_VFS_JOB (job));
   return TRUE;
 }
